/*
    ティラノビルダープラグイン開発用のテンプレート
    まず、このファイルを編集してプラグイン開発を試してみると良いでしょう。    
*/

'use strict';
module.exports = class plugin_setting {
    
    constructor(TB) {
        
        /* TBはティラノビルダーの機能にアクセスするためのインターフェスを提供する */
        this.TB = TB;
        
        /* プラグイン名を格納する */
        this.name= TB.$.s("背景変更（改）");
        
        /*プラグインの説明文を格納する*/
        this.plugin_text= TB.$.s("背景変更の際、自動的にメッセージボックスを隠すことができます");
        
        /*プラグイン説明用の画像ファイルを指定する。プラグインフォルダに配置してください*/
        this.plugin_img = "no_image";
        
    }
    
    
    /* プラグインをインストールを実行した時１度だけ走ります。フォルダのコピーなどにご活用ください。*/
    triggerInstall(){
        
        /*
        //プラグインからプロジェクトにファイルをコピーするサンプルです 
        var project_path = TB.getProjectPath() ; 
        var from_path = project_path + "data/others/plugin/plugin_template/copy_folder";
        var to_path = project_path + "data/image/copy_folder";
        TB.io.copy(from_path,to_path);
        */
    }
    
    /*
        追加するコンポーネントを定義します。
    */
    
    defineComponents(){
        
        var cmp = {};
        var TB = this.TB;
        
        
        /*
            cmp配列
            cmpにプラグイン用のコンポーネントを定義していきます。
            配列名にはタグ名を指定してください。
            他のタグと被らないように世界で一つだけの名称になるように工夫してください。
            （自分の所持しているドメイン名を含めるなど）
        */
        
        /*
            sample_component_1 
            次のパラメータのサンプルを設置
            Image:イメージ選択
            
        */
        
        cmp["bg_no_message"] = {
            
            "info":{
                
                "default":true, /*trueを指定するとコンポーネントがデフォルトで配置されます。*/
                "name":TB.$.s("背景変更（改）"), /* コンポーネント名称 */
                "help":TB.$.s("背景変更の際、自動的にメッセージボックスを隠すことができます"), /* コンポーネントの説明を記述します */ 
                "icon":TB.$.s("s-icon-star-full") /* ここは変更しないでください */
                
            },
            
            /* コンポーネントの情報の詳細を定義します */
            
            "component":{
                
                name : TB.$.s("背景変更（改）"), /* コンポーネント名称 */
                component_type : "Image", /*タイムラインのコンポーネントタイプ */
                
                /*ビューに渡す値*/
                default_view : {
                    base_img_url : "data/bgimage/",  /*画像選択のベースとなるフォルダを指定*/
                    icon : "s-icon-star-full", /*変更しない*/
                    icon_color : "#FFFF99", /*変更しない*/
                    category : "plugin" /*変更しない*/
                },
                
                /*変更しない*/
                param_view : {
                },
            
                /* コンポーネントのパラメータを定義していきます */
                param:{
                    
                    /*パラメータを指定します。storageはパラメータ名を表しています。*/
                    /*画像選択の例*/
                    "storage" : {
                        type : "ImageSelect",   /*パラメータのタイプです。これは画像選択の場合*/
                        file_path : "bgimage/", /* 背景画像からデフォルト選択するようになっていること。 */
                        base_img_url : "data/bgimage/", /* 選択対象のフォルダを指定する */
                        name : TB.$.s("背景画像"), /* パラメータ名 */
                        help : TB.$.s("指定した背景画像に切り替えます"), /*パラメータの説明　画面下部のヘルプスペースに表示されます*/
                        vital : true, /*必須項目か否か。できる限り必須としてデフォルト値を設定しておくことを推奨します。*/
                        default_val : "", /*コンポーネントを配置したの初期値を設定できます*/
                        line_preview: "on", /*タイムライン上でプレビューするか否か*/
                        validate : {
                            required : true
                        }
                    },
                    
                    /*数値入力の例*/
                    "time" : {
                        type : "Num", /*Numは数字入力を設定できます*/
                        name : "時間", /*パラメータ名*/
                        unit : "ﾐﾘ秒", /*単位を表示できます*/
                        help : TB.$.s("指定した時間をかけて背景が切り替わります"),
                        
                        default_val : 1000, /*初期値*/
                        
                        /*spinnerは数値をスピナー形式で表現します*/
                        spinner : {
                            min : 0, /*入力の最小値*/
                            max : 10000, /*入力の最大値*/
                            step : 500 /*スピナーを１回動かした時のステップ値*/
                        },
                        
                        validate : {
                            number : true /*数値か否かのチェックを有効化*/
                        }
        
                    },
                    
                    "wait_time" : {
                        type : "Num", /*Numは数字入力を設定できます*/
                        name : "待ち時間", /*パラメータ名*/
                        unit : "ﾐﾘ秒", /*単位を表示できます*/
                        help : TB.$.s("背景を表示したあとの待ち時間をしていできます。"),
                        
                        default_val : 1000, /*初期値*/
                        
                        /*spinnerは数値をスピナー形式で表現します*/
                        spinner : {
                            min : 0, /*入力の最小値*/
                            max : 10000, /*入力の最大値*/
                            step : 500 /*スピナーを１回動かした時のステップ値*/
                        },
                        
                        validate : {
                            number : true /*数値か否かのチェックを有効化*/
                        }
        
                    },
                    
                    
                },
                
                /*
                    途中からプレビューの時に実行するタグを返す。
                    例えば背景変更の機能をもったコンポーネントの場合、
                    途中からプレビューのときに背景変更のタグを実行しておかないと
                    途中からプレビューにこのコンポーネントが反映されません。
                    timeなどの時間は短くしておく必要があります。
                */
                /*
                preview_tag:function(preview,cmp){
                    
                    var storage = cmp.data.pm["storage"]; 
                    
                    //返却用のタグを設定
                    preview.code_current_bg ="[bg time=10 storage="+storage+" ] \n";
                             
                },
                */
            
            }
            
        };
                
        return cmp;
    
        
    }
    
    test(){
        
        
    }
        
}

